@@ -1,3 +1,5 @@
+import datetime
+
 import hjson
 
 from .htmlcomponents import *
@@ -150,27 +152,33 @@ class AgGrid(JustpyBaseComponent):
             columnDefs = []
             if len(lod)>0:
                 header=lod[0]
-                for key in header.keys():
-                    columnDefs.append({'field':key})
+                for key, value in header.items():
+                    if isinstance(value, int) or isinstance(value, float):
+                        col_filter = "agNumberColumnFilter"
+                    elif isinstance(value, datetime.date) or isinstance(value, datetime.date):
+                        col_filter = "agDateColumnFilter"
+                    else:
+                        col_filter = True  # Use default filter
+                    columnDefs.append(Dict({'field': key, "filter": col_filter}))
         self.options.columnDefs=columnDefs
         self.options.rowData=lod
 
     async def run_api(self, command, page):
-        await page.run_javascript(f"""cached_grid_def[{self.grid_id}].api.{command}""")
+        await page.run_javascript(f"""cached_grid_def['{self.grid_id}'].api.{command}""")
 
     async def select_all_rows(self, page):
         await page.run_javascript(
-            f"""cached_grid_def[{self.grid_id}].api.selectAll()"""
+            f"""cached_grid_def['{self.grid_id}'].api.selectAll()"""
         )
 
     async def deselect_rows(self, page):
         await page.run_javascript(
-            f"""cached_grid_def[{self.grid_id}].api.deselectAll()"""
+            f"""cached_grid_def['{self.grid_id}'].api.deselectAll()"""
         )
 
     async def apply_transaction(self, transaction, page):
         await page.run_javascript(
-            f"""cached_grid_def[{self.grid_id}].api.applyTransaction({transaction.__repr__()})"""
+            f"""cached_grid_def['{self.grid_id}'].api.applyTransaction({transaction.__repr__()})"""
         )
 
     def convert_object_to_dict(self):
